****************
Mopidy-MFE
****************

Mopidy-MFE is a `Mopidy <http://www.mopidy.com/>`_ web extension.


Installation
============

Install by running::

    sudo pip install Mopidy-MFE

Upgrade by running::

    sudo pip install Mopidy-MFE --upgrade

Project resources
=================

- `Source code <https://github.com/LukeMcDonnell/mopidy-MFE>`_
- `Issue tracker <https://github.com/LukeMcDonnell/mopidy-MFE/issues>`_


Changelog
=========
v0.2.1 (2015-11-06)
-------------------
- Added "Favourites" functionality
- Fixed bug preventing "Recently Played" items persisting between sessions.


v0.2.0 (2015-11-05)
-------------------
- Added "My Music" section
- Recently Played items in "My Music"
- Fixed many layout and design errors
- Now Playing/Artists/Albums pages all show dynamic backgrounds based on content.
- Added context menus to provide further queueing options
- Various bug fixes/optimizations

v0.1.2 (2015-10-31)
-------------------

- Initial release.

